configure_web_bootloader

Function configure_web_bootloader 

pub fn configure_web_bootloader(loader: Bootloader) -> Bootloader
Registers the codec/lisp boot codec and the web-shell serve verb onto an existing Bootloader, returning it for further composition. A downstream binary can stack this with other serve libraries (e.g. MCP) onto one bootloader.